@@ -1,8 +1,11 @@
 package App::Oozie;
-$App::Oozie::VERSION = '0.013';
+
 use 5.014;
 use strict;
 use warnings;
+
+our $VERSION = '0.014'; # VERSION
+
 use namespace::autoclean -except => [qw/_options_data _options_config/];
 
 use Moo;
@@ -32,7 +35,7 @@ sub run {
     my $action_to_class = find_plugins('App::Oozie::Action');
 
     if ( $debug ) {
-        $logger->debug( sprintf "Found: %s", $_ )
+        $logger->debug( sprintf 'Found: %s', $_ )
             for sort keys %{ $action_to_class };
     }
 
@@ -60,8 +63,8 @@ sub run {
         ( map { '-I' . $_ } @INC ),
         '-M' . $class,
         '-E', "$class->new_with_options->run",
-        '--',
-        @ARGV
+        q{--},
+        @ARGV,
     );
 
     if ( $debug ) {
@@ -70,7 +73,7 @@ sub run {
                     [  \@cmd ],
                     [qw( cmd )]
                 )->Indent( 0 );
-        $logger->debug( sprintf "Executing: %s", $d->Dump );
+        $logger->debug( sprintf 'Executing: %s', $d->Dump );
     }
 
     exec @cmd;
@@ -82,15 +85,11 @@ __END__
 
 =pod
 
-=encoding UTF-8
+=encoding utf8
 
 =head1 NAME
 
-App::Oozie
-
-=head1 VERSION
-
-version 0.013
+App::Oozie - Tooling/wrappers for Oozie job deployment and scheduling
 
 =head1 SYNOPSIS
 
@@ -102,10 +101,6 @@ Oozie Workflow jobs are Directed Acyclical Graphs (DAGs) of actions.
 The sets of tools in this package tries to make it easier to generate,
 deploy and schedule Oozie application specs and files.
 
-=head1 NAME
-
-App::Oozie - Tooling/wrappers for Oozie job deployment and scheduling
-
 =head1 Methods
 
 =head2 debug
@@ -119,25 +114,5 @@ L<https://oozie.apache.org>.
 L<App::Oozie::Deploy>, L<App::Oozie::Run>, L<App::Oozie::Update::Coordinator>,
 L<http://oozie.apache.org>.
 
-=head1 AUTHORS
-
-=over 4
-
-=item *
-
-David Morel
-
-=item *
-
-Burak Gursoy
-
-=back
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2023 by Booking.com.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
+
