@@ -1,9 +1,11 @@
 package App::Oozie::Compare::LocalToHDFS;
-$App::Oozie::Compare::LocalToHDFS::VERSION = '0.013';
+
 use 5.014;
 use strict;
 use warnings;
 
+our $VERSION = '0.014'; # VERSION
+
 use namespace::autoclean -except => [qw/_options_data _options_config/];
 
 use App::Oozie::Types::Common qw( IsDir );
@@ -71,12 +73,16 @@ sub run {
     my $delete = $self->delete;
     my $logger = $self->logger;
 
-    $logger->info(sprintf "Comparing file://%s to hdfs://%s", $self->local_path, $self->hdfs_path );
+    $logger->info(
+        sprintf 'Comparing file://%s to hdfs://%s',
+                $self->local_path,
+                $self->hdfs_path,
+    );
 
     my($rm_files, $rm_dirs) = $self->compare_local_to_hdfs;
 
     if ( 0 == @{ $rm_files } + @{ $rm_dirs } ) {
-        $logger->info( "Nothing to delete" );
+        $logger->info( 'Nothing to delete' );
         return;
     }
 
@@ -84,7 +90,7 @@ sub run {
 
     if ( ! $delete ) {
         for my $path ( @hdfs_to_delete ) {
-            $logger->info( "Would have deleted $path" );
+            $logger->info( sprintf 'Would have deleted %s', $path );
         }
         return;
     }
@@ -92,13 +98,17 @@ sub run {
     my $hdfs = $self->hdfs;
 
     for my $path ( @hdfs_to_delete ) {
-        $logger->info( "Attempting to delete $path" );
+        $logger->info( sprintf 'Attempting to delete %s', $path );
         eval {
             $hdfs->delete( $path );
             1;
         } or do {
             my $eval_error = $@ || 'Zombie error';
-            $logger->warn( "Skipping. Failed to delete $path: $eval_error" );
+            $logger->warn(
+                sprintf 'Skipping. Failed to delete %s: %s',
+                        $path,
+                        $eval_error,
+            );
         };
     }
 
@@ -148,9 +158,10 @@ sub find_local_files {
     my(@local_dirs, @local_files);
     File::Find::find {
         wanted => sub {
-            (my $f = $_) =~ s{ \Q$local_path\E [/]? }{}xms;
+            my $name = $_;
+            (my $f = $name) =~ s{ \Q$local_path\E [/]? }{}xms;
             return if ! $f;
-            my $d = -d $_ ? \@local_dirs : \@local_files;
+            my $d = -d $name ? \@local_dirs : \@local_files;
             push @{ $d }, $f;
         },
         no_chdir => 1,
@@ -165,15 +176,13 @@ __END__
 
 =pod
 
-=encoding UTF-8
+=encoding utf8
+
+=for Pod::Coverage BUILD
 
 =head1 NAME
 
-App::Oozie::Compare::LocalToHDFS
-
-=head1 VERSION
-
-version 0.013
+App::Oozie::Compare::LocalToHDFS - Commpares the local files against the HDFS deployment.
 
 =head1 SYNOPSIS
 
@@ -183,12 +192,6 @@ TBD
 
 TBD
 
-=for Pod::Coverage BUILD
-
-=head1 NAME
-
-App::Oozie::Compare::LocalToHDFS - Commpares the local files against the HDFS deployment.
-
 =head1 Methods
 
 =head2 compare_local_to_hdfs
@@ -205,25 +208,4 @@ App::Oozie::Compare::LocalToHDFS - Commpares the local files against the HDFS de
 
 L<App::Oozie>.
 
-=head1 AUTHORS
-
-=over 4
-
-=item *
-
-David Morel
-
-=item *
-
-Burak Gursoy
-
-=back
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2023 by Booking.com.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
