@@ -1,8 +1,11 @@
 package App::Oozie::Deploy::Validate::DAG::Vertex;
-$App::Oozie::Deploy::Validate::DAG::Vertex::VERSION = '0.013';
+
 use 5.014;
 use strict;
 use warnings;
+
+our $VERSION = '0.014'; # VERSION
+
 use namespace::autoclean -except => [qw/_options_data _options_config/];
 use overload
     '""' => \&stringify,
@@ -45,15 +48,11 @@ __END__
 
 =pod
 
-=encoding UTF-8
+=encoding utf8
 
 =head1 NAME
 
-App::Oozie::Deploy::Validate::DAG::Vertex
-
-=head1 VERSION
-
-version 0.013
+App::Oozie::Deploy::Validate::DAG::Vertex - Part of the Oozie workflow DAG validator.
 
 =head1 SYNOPSIS
 
@@ -63,10 +62,6 @@ TBD
 
 TBD
 
-=head1 NAME
-
-App::Oozie::Deploy::Validate::DAG::Vertex - Part of the Oozie workflow DAG validator.
-
 =head1 Methods
 
 =head2 is_eq
@@ -79,25 +74,4 @@ App::Oozie::Deploy::Validate::DAG::Vertex - Part of the Oozie workflow DAG valid
 
 L<App::Oozie>.
 
-=head1 AUTHORS
-
-=over 4
-
-=item *
-
-David Morel
-
-=item *
-
-Burak Gursoy
-
-=back
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2023 by Booking.com.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
