@@ -1,8 +1,11 @@
 package App::Oozie::Deploy::Validate::Meta;
-$App::Oozie::Deploy::Validate::Meta::VERSION = '0.013';
+
 use 5.014;
 use strict;
 use warnings;
+
+our $VERSION = '0.014'; # VERSION
+
 use namespace::autoclean -except => [qw/_options_data _options_config/];
 
 use App::Oozie::Serializer;
@@ -10,7 +13,11 @@ use App::Oozie::Types::Workflow qw(
     WorkflowMeta
     WorkflowMetaOrDummy
 );
-use App::Oozie::Constants qw( DEFAULT_META_FILENAME );
+use App::Oozie::Constants qw(
+    DEFAULT_META_FILENAME
+    EMPTY_STRING
+);
+
 use Moo;
 use MooX::Options;
 use Types::Standard qw( InstanceOf Str );
@@ -106,7 +113,8 @@ sub maybe_decode {
         $logger->info(
             sprintf 'Meta file %s exists, but seems to be an invalid one. Ignoring%s.',
                         $meta_file,
-                        $self->verbose ? '' : ' (enable --verbose to see the validation errors)',
+                        $self->verbose ? EMPTY_STRING
+                                       : ' (enable --verbose to see the validation errors)',
         );
         if ( $self->verbose ) {
             for my $i ( 0..$#{ $reason } ) {
@@ -127,15 +135,11 @@ __END__
 
 =pod
 
-=encoding UTF-8
+=encoding utf8
 
 =head1 NAME
 
-App::Oozie::Deploy::Validate::Meta
-
-=head1 VERSION
-
-version 0.013
+App::Oozie::Deploy::Validate::Meta - Workflow meta file validator
 
 =head1 SYNOPSIS
 
@@ -145,10 +149,6 @@ TBD
 
 TBD
 
-=head1 NAME
-
-App::Oozie::Deploy::Validate::Meta - Workflow meta file validator
-
 =head1 Methods
 
 =head2 coord_directive
@@ -171,25 +171,4 @@ App::Oozie::Deploy::Validate::Meta - Workflow meta file validator
 
 L<App::Oozie>.
 
-=head1 AUTHORS
-
-=over 4
-
-=item *
-
-David Morel
-
-=item *
-
-Burak Gursoy
-
-=back
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2023 by Booking.com.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
