@@ -1,8 +1,11 @@
 package App::Oozie::Deploy::Validate::Oozie;
-$App::Oozie::Deploy::Validate::Oozie::VERSION = '0.013';
+
 use 5.014;
 use strict;
 use warnings;
+
+our $VERSION = '0.014'; # VERSION
+
 use namespace::autoclean -except => [qw/_options_data _options_config/];
 
 use App::Oozie::Types::Common qw( IsExecutable );
@@ -29,7 +32,7 @@ has oozie_uri => (
 
 sub validate {
     my $self = shift;
-    my $oozie_xmlfile = shift || die "No xml specified!";
+    my $oozie_xmlfile = shift || die 'No xml specified!';
 
     if ( ! -e $oozie_xmlfile ) {
         die "Not a file: $oozie_xmlfile";
@@ -37,10 +40,13 @@ sub validate {
 
     my($validation_errors, $total_errors);
 
-    my $command;
-    $self->logger->info( "Oozie validate for $oozie_xmlfile" );
+    $self->logger->info(
+        sprintf 'Oozie validate for %s',
+                $oozie_xmlfile,
+    );
+
     my $oozie_uri = $self->oozie_uri;
-    $command = [
+    my $command   = [
         $self->oozie_cli,
         validate => $oozie_xmlfile,
     ];
@@ -85,15 +91,11 @@ __END__
 
 =pod
 
-=encoding UTF-8
+=encoding utf8
 
 =head1 NAME
 
-App::Oozie::Deploy::Validate::Oozie
-
-=head1 VERSION
-
-version 0.013
+App::Oozie::Deploy::Validate::Oozie - Part of the Oozie Workflow validator kit.
 
 =head1 SYNOPSIS
 
@@ -103,10 +105,6 @@ TBD
 
 TBD
 
-=head1 NAME
-
-App::Oozie::Deploy::Validate::Oozie - Part of the Oozie Workflow validator kit.
-
 =head1 Methods
 
 =head2 oozie_uri
@@ -117,25 +115,4 @@ App::Oozie::Deploy::Validate::Oozie - Part of the Oozie Workflow validator kit.
 
 L<App::Oozie>.
 
-=head1 AUTHORS
-
-=over 4
-
-=item *
-
-David Morel
-
-=item *
-
-Burak Gursoy
-
-=back
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2023 by Booking.com.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
