@@ -1,8 +1,11 @@
 package App::Oozie::Deploy::Validate::Spec::Bundle;
-$App::Oozie::Deploy::Validate::Spec::Bundle::VERSION = '0.013';
+
 use 5.014;
 use strict;
 use warnings;
+
+our $VERSION = '0.014'; # VERSION
+
 use namespace::autoclean -except => [qw/_options_data _options_config/];
 
 use Moo;
@@ -62,15 +65,11 @@ __END__
 
 =pod
 
-=encoding UTF-8
+=encoding utf8
 
 =head1 NAME
 
-App::Oozie::Deploy::Validate::Spec::Bundle
-
-=head1 VERSION
-
-version 0.013
+App::Oozie::Deploy::Validate::Spec::Bundle - Part of the Oozie Workflow validator kit.
 
 =head1 SYNOPSIS
 
@@ -80,10 +79,6 @@ TBD
 
 TBD
 
-=head1 NAME
-
-App::Oozie::Deploy::Validate::Spec::Bundle - Part of the Oozie Workflow validator kit.
-
 =head1 Methods
 
 =head2 verify
@@ -92,25 +87,4 @@ App::Oozie::Deploy::Validate::Spec::Bundle - Part of the Oozie Workflow validato
 
 L<App::Oozie>.
 
-=head1 AUTHORS
-
-=over 4
-
-=item *
-
-David Morel
-
-=item *
-
-Burak Gursoy
-
-=back
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2023 by Booking.com.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
