@@ -1,14 +1,18 @@
 package App::Oozie::Deploy::Validate::Spec::Coordinator;
-$App::Oozie::Deploy::Validate::Spec::Coordinator::VERSION = '0.013';
+
 use 5.014;
 use strict;
 use warnings;
+
+our $VERSION = '0.014'; # VERSION
+
 use namespace::autoclean -except => [qw/_options_data _options_config/];
 
 use Moo;
 use MooX::Options;
 use List::MoreUtils qw( uniq );
 use App::Oozie::Types::Common qw( IsFile );
+use App::Oozie::Constants qw( EMPTY_STRING );
 
 with qw(
     App::Oozie::Role::Log
@@ -60,7 +64,7 @@ sub verify {
             );
 
             for my $property ( @{ $h->{property} } ) {
-              my $property_name = defined($property->{name})? $property->{name} : "";
+              my $property_name = defined($property->{name})? $property->{name} : EMPTY_STRING;
               #if ($property_name eq 'startDate' || $property_name eq 'endDate') {
               if (exists $blacklist{$property_name}) {
                  push @restricted_properties, $h->{$key};
@@ -99,15 +103,11 @@ __END__
 
 =pod
 
-=encoding UTF-8
+=encoding utf8
 
 =head1 NAME
 
-App::Oozie::Deploy::Validate::Spec::Coordinator
-
-=head1 VERSION
-
-version 0.013
+App::Oozie::Deploy::Validate::Spec::Coordinator - Part of the Oozie Workflow validator kit.
 
 =head1 SYNOPSIS
 
@@ -117,10 +117,6 @@ TBD
 
 TBD
 
-=head1 NAME
-
-App::Oozie::Deploy::Validate::Spec::Coordinator - Part of the Oozie Workflow validator kit.
-
 =head1 Methods
 
 =head2 verify
@@ -129,25 +125,4 @@ App::Oozie::Deploy::Validate::Spec::Coordinator - Part of the Oozie Workflow val
 
 L<App::Oozie>.
 
-=head1 AUTHORS
-
-=over 4
-
-=item *
-
-David Morel
-
-=item *
-
-Burak Gursoy
-
-=back
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2023 by Booking.com.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
