@@ -1,10 +1,17 @@
 package App::Oozie::Deploy::Validate::Spec::Workflow;
-$App::Oozie::Deploy::Validate::Spec::Workflow::VERSION = '0.013';
+
 use 5.014;
 use strict;
 use warnings;
+
+our $VERSION = '0.014'; # VERSION
+
 use namespace::autoclean -except => [qw/_options_data _options_config/];
 
+use App::Oozie::Constants qw(
+    STAT_SIZE
+);
+
 use File::Basename;
 use Moo;
 use MooX::Options;
@@ -40,7 +47,8 @@ has file_size => (
     is      => 'ro',
     default => sub {
         my $file = shift->file;
-        my $wf_size = (stat $file )[7] || die "$file either has zero size or I've failed to locate it";
+        my $wf_size = (stat $file )[STAT_SIZE]
+                        || die "$file either has zero size or I've failed to locate it";
         $wf_size;
     }
 );
@@ -110,38 +118,44 @@ ETOOFAT
         $validation_errors++;
         $total_errors++;
     }
-        
-	my $validation_queue_check = 0;
+
+    my $validation_queue_check = 0;
 
     # ====================================================================== #
     # TODO: we already have the decoded XML. Get rid of this file read
     #
     # check any action contains root.default or root.mapred queue conf (spark,hive or shell)
-    open my $FH, '<', $file or die "Cannot open $file";
+    open my $FH, '<', $file or die "Cannot open $file"; ## no critic (InputOutput::RequireBriefOpen)
     while(my $String = <$FH>) {
         if (
-                $String =~ /(root.default)$/
-            ||  $String =~ /(root.mapred)$/
+                $String =~ m{ (root.default) \z }xms
+            ||  $String =~ m{ (root.mapred)  \z }xms
         ) {
             $logger->error(
-                "FIXME !!! queue configuration parameter in workflow.xml is set to default or mapred; you are not allowed to deploy workflows in root.mapred or root.default queue."
+                'FIXME !!! queue configuration parameter in workflow.xml is set to default or mapred; you are not allowed to deploy workflows in root.mapred or root.default queue.'
             );
             $validation_errors++;
             $total_errors++;
         }
 
         if (
-                $String =~ /(mapreduce.job.queuename)/
-            ||  $String =~ /(spark.yarn.queue)/
+                $String =~ m{ (mapreduce.job.queuename) }xms
+            ||  $String =~ m{ (spark.yarn.queue) }xms
         ) {
             $validation_queue_check++;
         }
     }
-    close $FH;
+    if ( ! close $FH ) {
+        $self->logger->warn(
+            sprintf 'Failed to close %s: %s',,
+                        $file,
+                        $!,
+        );
+    }
     # ====================================================================== #
 
     if ( !$validation_queue_check ) {
-        $logger->error( "FIXME !!! queue configuration parameter in workflow.xml is not mentioned..Please set queue parameter either using --conf spark.yarn.queue or mapreduce.job.queuename. you are not allowed to deploy workflows in root.mapred or root.default queue." );
+        $logger->error( 'FIXME !!! queue configuration parameter in workflow.xml is not mentioned..Please set queue parameter either using --conf spark.yarn.queue or mapreduce.job.queuename. you are not allowed to deploy workflows in root.mapred or root.default queue.' );
         $validation_errors++;
         $total_errors++;
     }
@@ -158,15 +172,18 @@ ETOOFAT
                     : undef
                     ;
 
-    $logger->info( "XML key validation for $file" );
+    $logger->info( sprintf 'XML key validation for %s', $file );
 
     # check some values in the XML files
     # in workflow.xml, check errorEmailTo, various params, and display a warning
 
+
+    my $error_email_field_name = 'errorEmailTo';
+
     my @contact_mail = $prop
                         ? (
                             map  { $_->{value} }
-                            grep { $_->{name} eq 'errorEmailTo' }
+                            grep { $_->{name} eq $error_email_field_name }
                             @{ $prop }
                             )
                         : ()
@@ -176,7 +193,7 @@ ETOOFAT
     my @queue_array = $global_prop
                     ? (
                         map  { $_->{value} }
-                        grep { $_->{name} =~ m{queuename} }
+                        grep { $_->{name} =~ m{ queuename }xms }
                         @{ $global_prop }
                         )
                     : ()
@@ -198,7 +215,7 @@ ETOOFAT
     foreach my $queue_value (@queue_array) {
         if ( $queue_value =~ 'default' || $queue_value =~ 'mapred' ) {
             $logger->error(
-                "FIXME !!! mapreduce.job.queuename parameter in workflow.xml is set to default or mapred; you are not allowed to deploy workflows in root.mapred or root.default queue"
+                'FIXME !!! mapreduce.job.queuename parameter in workflow.xml is set to default or mapred; you are not allowed to deploy workflows in root.mapred or root.default queue.'
             );
             $validation_errors++;
             $total_errors++;
@@ -207,7 +224,8 @@ ETOOFAT
 
     if ( ! @contact_mail ) {
         $logger->warn(
-            "FIXME !!! no errorEmailTo parameter in workflow.xml; you will not get error emails"
+            sprintf 'FIXME !!! no `%s` parameter in workflow.xml; you will not get error emails',
+                        $error_email_field_name,
         );
         $validation_errors++;
         $total_errors++;
@@ -215,7 +233,11 @@ ETOOFAT
     else {
         my $validator = $self->email_validator;
         if ( ! $validator->( $self, @contact_mail ) ) {
-            $logger->warn( sprintf "errorEmailTo=`%s` is invalid", @contact_mail );
+            $logger->warn(
+                sprintf '%s=`%s` is invalid',
+                        $error_email_field_name,
+                        @contact_mail
+            );
             $validation_errors++;
             $total_errors++;
         }
@@ -285,14 +307,14 @@ sub verify_queue_name {
     }
 
     foreach my $action_name (keys %{ $action } ) {
-        my $action = $action->{$action_name};
+        my $this_action = $action->{$action_name};
         foreach my $job_type (
-            grep { exists $action->{ $_ } }
+            grep { exists $this_action->{ $_ } }
                 @JOB_TYPES_NEEDING_QUEUE
         ) {
-            my $a_prop =  $action->{ $job_type }{configuration}
-                            && $action->{ $job_type }{configuration}{property}
-                        ? $action->{ $job_type }{configuration}{property}
+            my $a_prop =  $this_action->{ $job_type }{configuration}
+                            && $this_action->{ $job_type }{configuration}{property}
+                        ? $this_action->{ $job_type }{configuration}{property}
                         : undef
                         ;
             if (
@@ -331,15 +353,11 @@ __END__
 
 =pod
 
-=encoding UTF-8
+=encoding utf8
 
 =head1 NAME
 
-App::Oozie::Deploy::Validate::Spec::Workflow
-
-=head1 VERSION
-
-version 0.013
+App::Oozie::Deploy::Validate::Spec::Workflow - Part of the Oozie Workflow validator kit.
 
 =head1 SYNOPSIS
 
@@ -349,10 +367,6 @@ TBD
 
 TBD
 
-=head1 NAME
-
-App::Oozie::Deploy::Validate::Spec::Workflow - Part of the Oozie Workflow validator kit.
-
 =head1 Methods
 
 =head2 file
@@ -375,25 +389,4 @@ App::Oozie::Deploy::Validate::Spec::Workflow - Part of the Oozie Workflow valida
 
 L<App::Oozie>.
 
-=head1 AUTHORS
-
-=over 4
-
-=item *
-
-David Morel
-
-=item *
-
-Burak Gursoy
-
-=back
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2023 by Booking.com.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
