@@ -1,5 +1,7 @@
 package App::Oozie::Forked::Template::ttree;
 
+## no critic
+
 # This is currently a fork.
 
 # See https://github.com/abw/Template2/pull/316
@@ -1029,17 +1031,9 @@ END_OF_HELP
 
 __END__
 
-=pod
-
-=encoding UTF-8
-
 =head1 NAME
 
-App::Oozie::Forked::Template::ttree
-
-=head1 VERSION
-
-version 0.013
+App::Oozie::Forked::Template::ttree - Backend of ttree
 
 =head1 SYNOPSIS
 
@@ -1049,10 +1043,6 @@ See L<Template::Tools::ttree|ttree>.
 
 See L<Template::Tools::ttree|ttree>.
 
-=head1 NAME
-
-App::Oozie::Forked::Template::ttree - Backend of ttree
-
 =head1 AUTHORS
 
 Andy Wardley E<lt>abw@wardley.orgE<gt>
@@ -1075,25 +1065,4 @@ modify it under the same terms as Perl itself.
 
 L<Template::Tools::ttree|ttree>
 
-=head1 AUTHORS
-
-=over 4
-
-=item *
-
-David Morel
-
-=item *
-
-Burak Gursoy
-
-=back
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2023 by Booking.com.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
