@@ -1,9 +1,11 @@
 package App::Oozie::Role::Fields::Common;
-$App::Oozie::Role::Fields::Common::VERSION = '0.013';
+
 use 5.014;
 use strict;
 use warnings;
 
+our $VERSION = '0.014'; # VERSION
+
 use namespace::autoclean -except => [qw/_options_data _options_config/];
 
 use App::Oozie::Types::Common qw( IsUserName );
@@ -34,7 +36,7 @@ option username => (
     isa     => IsUserName,
     short   => 'user',
     format  => 's',
-    doc     => "User name under which the job should be submitted. Not set by default and commands will be executed as the effective user",
+    doc     => 'User name under which the job should be submitted. Not set by default and commands will be executed as the effective user',
 );
 
 has execute_as_someone_else => (
@@ -83,15 +85,11 @@ __END__
 
 =pod
 
-=encoding UTF-8
+=encoding utf8
 
 =head1 NAME
 
-App::Oozie::Role::Fields::Common
-
-=head1 VERSION
-
-version 0.013
+App::Oozie::Role::Fields::Common - Overridable common fields for internal programs/libs.
 
 =head1 SYNOPSIS
 
@@ -104,10 +102,6 @@ version 0.013
 This is a Role to be consumed by Oozie tooling classes and
 defines various fields.
 
-=head1 NAME
-
-App::Oozie::Role::Fields::Common - Overridable common fields for internal programs/libs.
-
 =head1 Accessors
 
 =head2 Overridable from cli
@@ -132,25 +126,4 @@ App::Oozie::Role::Fields::Common - Overridable common fields for internal progra
 
 L<App::Oozie>.
 
-=head1 AUTHORS
-
-=over 4
-
-=item *
-
-David Morel
-
-=item *
-
-Burak Gursoy
-
-=back
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2023 by Booking.com.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
