@@ -1,13 +1,16 @@
 package App::Oozie::Role::Fields::Generic;
-$App::Oozie::Role::Fields::Generic::VERSION = '0.013';
+
 use 5.014;
 use strict;
 use warnings;
 
+our $VERSION = '0.014'; # VERSION
+
 use namespace::autoclean -except => [qw/_options_data _options_config/];
 
 use App::Oozie::Constants qw(
     DEFAULT_TIMEOUT
+    DEFAULT_MAX_RETRY
 );
 
 use Moo::Role;
@@ -29,7 +32,7 @@ option force => (
 option max_retry => (
     is       => 'rw',
     isa      => Int,
-    default  => sub { 3 },
+    default  => sub { DEFAULT_MAX_RETRY },
     doc      => 'Maximum number of retries for various function calls',
 );
 
@@ -52,7 +55,7 @@ has effective_username => (
     is      => 'ro',
     default => sub {
         (getpwuid $<)[0]
-            || die "Unable to locate the effective user name";
+            || die 'Unable to locate the effective user name';
     },
 );
 
@@ -62,15 +65,11 @@ __END__
 
 =pod
 
-=encoding UTF-8
+=encoding utf8
 
 =head1 NAME
 
-App::Oozie::Role::Fields::Generic
-
-=head1 VERSION
-
-version 0.013
+Overridable generic fields for internal programs/libs.
 
 =head1 SYNOPSIS
 
@@ -83,10 +82,6 @@ version 0.013
 This is a Role to be consumed by Oozie tooling classes and
 defines various fields.
 
-=head1 NAME
-
-Overridable generic fields for internal programs/libs.
-
 =head1 Accessors
 
 =head2 Overridable from cli
@@ -109,25 +104,4 @@ Overridable generic fields for internal programs/libs.
 
 L<App::Oozie>.
 
-=head1 AUTHORS
-
-=over 4
-
-=item *
-
-David Morel
-
-=item *
-
-Burak Gursoy
-
-=back
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2023 by Booking.com.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
