@@ -1,8 +1,11 @@
 package App::Oozie::Role::Fields::Objects;
-$App::Oozie::Role::Fields::Objects::VERSION = '0.013';
+
 use 5.014;
 use strict;
 use warnings;
+
+our $VERSION = '0.014'; # VERSION
+
 use namespace::autoclean -except => [qw/_options_data _options_config/];
 
 use App::Oozie::Constants qw(
@@ -90,15 +93,11 @@ __END__
 
 =pod
 
-=encoding UTF-8
+=encoding utf8
 
 =head1 NAME
 
-App::Oozie::Role::Fields::Objects
-
-=head1 VERSION
-
-version 0.013
+App::Oozie::Role::Fields::Objects - Overridable objects for internal programs/libs.
 
 =head1 SYNOPSIS
 
@@ -111,10 +110,6 @@ version 0.013
 This is a Role to be consumed by Oozie tooling classes and
 defines various fields.
 
-=head1 NAME
-
-App::Oozie::Role::Fields::Objects - Overridable objects for internal programs/libs.
-
 =head1 Accessors
 
 =head2 Overridable from cli
@@ -139,25 +134,4 @@ App::Oozie::Role::Fields::Objects - Overridable objects for internal programs/li
 
 L<App::Oozie>.
 
-=head1 AUTHORS
-
-=over 4
-
-=item *
-
-David Morel
-
-=item *
-
-Burak Gursoy
-
-=back
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2023 by Booking.com.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
