@@ -1,8 +1,11 @@
 package App::Oozie::Role::Fields::Path;
-$App::Oozie::Role::Fields::Path::VERSION = '0.013';
+
 use 5.014;
 use strict;
 use warnings;
+
+our $VERSION = '0.014'; # VERSION
+
 use namespace::autoclean -except => [qw/_options_data _options_config/];
 
 use App::Oozie::Types::Common qw( IsExecutable IsFile IsDir );
@@ -23,7 +26,7 @@ option oozie_client_jar => (
     isa      => IsFile,
     format   => 's',
     doc      => 'Full path to the Oozie client jar containing the XML schemas',
-    default  => sub { '/usr/lib/oozie/lib/oozie-client.jar' }
+    default  => sub { '/usr/lib/oozie/lib/oozie-client.jar' },
 );
 
 option local_oozie_code_path => (
@@ -49,15 +52,11 @@ __END__
 
 =pod
 
-=encoding UTF-8
+=encoding utf8
 
 =head1 NAME
 
-App::Oozie::Role::Fields::Path
-
-=head1 VERSION
-
-version 0.013
+App::Oozie::Role::Fields::Path - Overridable paths for internal programs/libs.
 
 =head1 SYNOPSIS
 
@@ -70,10 +69,6 @@ version 0.013
 This is a Role to be consumed by Oozie tooling classes and
 defines various fields.
 
-=head1 NAME
-
-App::Oozie::Role::Fields::Path - Overridable paths for internal programs/libs.
-
 =head1 Accessors
 
 =head2 Overridable from cli
@@ -88,25 +83,5 @@ App::Oozie::Role::Fields::Path - Overridable paths for internal programs/libs.
 
 L<App::Oozie>.
 
-=head1 AUTHORS
-
-=over 4
-
-=item *
-
-David Morel
-
-=item *
-
-Burak Gursoy
-
-=back
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2023 by Booking.com.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
+
