@@ -1,8 +1,11 @@
 package App::Oozie::Role::Meta;
-$App::Oozie::Role::Meta::VERSION = '0.013';
+
 use 5.014;
 use strict;
 use warnings;
+
+our $VERSION = '0.014'; # VERSION
+
 use namespace::autoclean -except => [qw/_options_data _options_config/];
 
 use App::Oozie::Deploy::Validate::Meta;
@@ -52,15 +55,11 @@ __END__
 
 =pod
 
-=encoding UTF-8
+=encoding utf8
 
 =head1 NAME
 
-App::Oozie::Role::Meta
-
-=head1 VERSION
-
-version 0.013
+App::Oozie::Role::Meta - Meta file related role.
 
 =head1 SYNOPSIS
 
@@ -73,10 +72,6 @@ version 0.013
 This is a Role to be consumed by Oozie tooling classes and
 defines various fields.
 
-=head1 NAME
-
-App::Oozie::Role::Meta - Meta file related role.
-
 =head1 Methods
 
 =head2 probe_meta
@@ -91,25 +86,4 @@ App::Oozie::Role::Meta - Meta file related role.
 
 L<App::Oozie>.
 
-=head1 AUTHORS
-
-=over 4
-
-=item *
-
-David Morel
-
-=item *
-
-Burak Gursoy
-
-=back
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2023 by Booking.com.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
