@@ -1,8 +1,11 @@
 package App::Oozie::Role::NameNode;
-$App::Oozie::Role::NameNode::VERSION = '0.013';
+
 use 5.014;
 use strict;
 use warnings;
+
+our $VERSION = '0.014'; # VERSION
+
 use namespace::autoclean -except => [qw/_options_data _options_config/];
 
 use Log::Log4perl;
@@ -44,15 +47,11 @@ __END__
 
 =pod
 
-=encoding UTF-8
+=encoding utf8
 
 =head1 NAME
 
-App::Oozie::Role::NameNode
-
-=head1 VERSION
-
-version 0.013
+App::Oozie::Role::NameNode - Hadoop NameNode related accessors.
 
 =head1 SYNOPSIS
 
@@ -65,10 +64,6 @@ version 0.013
 This is a Role to be consumed by Oozie tooling classes and
 defines various fields.
 
-=head1 NAME
-
-App::Oozie::Role::NameNode - Hadoop NameNode related accessors.
-
 =head1 Accessors
 
 =head2 Overridable from cli
@@ -85,25 +80,5 @@ App::Oozie::Role::NameNode - Hadoop NameNode related accessors.
 
 L<App::Oozie>.
 
-=head1 AUTHORS
-
-=over 4
-
-=item *
-
-David Morel
-
-=item *
-
-Burak Gursoy
-
-=back
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2023 by Booking.com.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
+
