@@ -1,9 +1,11 @@
 package App::Oozie::Serializer;
-$App::Oozie::Serializer::VERSION = '0.013';
+
 use 5.014;
 use strict;
 use warnings;
 
+our $VERSION = '0.014'; # VERSION
+
 use App::Oozie::Util::Plugin qw(
     find_plugins
     load_plugin
@@ -51,7 +53,7 @@ sub BUILD {
 
     if ( ! $s ) {
         my $default = 'dummy';
-        warn sprintf "%s is an unknown serializer, falling back to %s",
+        warn sprintf '%s is an unknown serializer, falling back to %s',
                         $args->{format},
                         $default,
         ;
@@ -61,7 +63,7 @@ sub BUILD {
 
     if ( ! $s ) {
         # Shouldn't happen, apart from a possible future code change
-        die "Failed to locate a serializer!";
+        die 'Failed to locate a serializer!';
     }
 
     $self->_set___object( load_plugin( $s )->new );
@@ -71,26 +73,26 @@ sub BUILD {
 
 sub encode {
     my $self = shift;
-    my $data = shift || die "Nothing to encode!";
+    my $data = shift || die 'Nothing to encode!';
 
-    die "The data to encode needs to be a reference" if ! ref $data;
+    die 'The data to encode needs to be a reference' if ! ref $data;
 
     $self->_assert_type( $data ) if $self->enforce_type;
 
-    $self->__object->encode( $data )
+    return $self->__object->encode( $data )
 }
 
 sub decode {
     my $self = shift;
-    my $data = shift || die "Nothing to decode!";
+    my $data = shift || die 'Nothing to decode!';
 
-    die "The data to decode can't be a reference!" if ref $data;
+    die q{The data to decode can't be a reference!} if ref $data;
 
     my $is_file = $self->slurp && $data !~ m{ \n }xms && -e $data && -f _;
 
     my $rv = $self->__object->decode(
           $is_file            ? do { local(@ARGV, $/) = $data; <> }
-        : $data eq 'meta.yml' ? die "Only a file name (which does not exist) passed as meta data"
+        : $data eq 'meta.yml' ? die 'Only a file name (which does not exist) passed as meta data'
                  : $data
     );
 
@@ -105,7 +107,7 @@ sub decode {
 
 sub _assert_type {
     my $self  = shift;
-    my $input = shift || die "No data specified to enforce a type!";
+    my $input = shift || die 'No data specified to enforce a type!';
     my $type  = $self->enforce_type || return;
 
     my $failed   = $type->validate_explain( $input, 'USER_INPUT' ) || return;
@@ -124,19 +126,18 @@ DID_NOT_PASS
 
 1;
 
+
 __END__
 
 =pod
 
-=encoding UTF-8
+=encoding utf8
+
+=for Pod::Coverage BUILD
 
 =head1 NAME
 
-App::Oozie::Serializer
-
-=head1 VERSION
-
-version 0.013
+App::Oozie::Serializer - Serializer for various formats.
 
 =head1 SYNOPSIS
 
@@ -151,12 +152,6 @@ version 0.013
 
 Internal serializer.
 
-=for Pod::Coverage BUILD
-
-=head1 NAME
-
-App::Oozie::Serializer - Serializer for various formats.
-
 =head1 Methods
 
 =head2 decode
@@ -177,25 +172,4 @@ App::Oozie::Serializer - Serializer for various formats.
 
 L<App::Oozie>.
 
-=head1 AUTHORS
-
-=over 4
-
-=item *
-
-David Morel
-
-=item *
-
-Burak Gursoy
-
-=back
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2023 by Booking.com.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
