@@ -1,21 +1,24 @@
 package App::Oozie::Serializer::YAML;
-$App::Oozie::Serializer::YAML::VERSION = '0.013';
+
 use 5.014;
 use strict;
 use warnings;
+
+our $VERSION = '0.014'; # VERSION
+
 use YAML::XS ();
 use Moo;
 
 sub encode {
     my $self = shift;
     my $data = shift;
-    YAML::XS::Dump( $data );
+    return YAML::XS::Dump( $data );
 }
 
 sub decode {
     my $self = shift;
     my $data = shift;
-    YAML::XS::Load( $data );
+    return YAML::XS::Load( $data );
 }
 
 1;
@@ -24,15 +27,11 @@ __END__
 
 =pod
 
-=encoding UTF-8
+=encoding utf8
 
 =head1 NAME
 
-App::Oozie::Serializer::YAML
-
-=head1 VERSION
-
-version 0.013
+App::Oozie::Serializer::YAML - YAML encoder/decoder.
 
 =head1 SYNOPSIS
 
@@ -47,10 +46,6 @@ version 0.013
 
 YAML encoder/decoder.
 
-=head1 NAME
-
-App::Oozie::Serializer::YAML - YAML encoder/decoder.
-
 =head1 Methods
 
 =head2 encode
@@ -61,25 +56,4 @@ App::Oozie::Serializer::YAML - YAML encoder/decoder.
 
 L<App::Oozie>. L<App::Oozie::Serializer>.
 
-=head1 AUTHORS
-
-=over 4
-
-=item *
-
-David Morel
-
-=item *
-
-Burak Gursoy
-
-=back
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2023 by Booking.com.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
