@@ -1,9 +1,11 @@
 package App::Oozie::Types::Common;
-$App::Oozie::Types::Common::VERSION = '0.013';
+
 use 5.014;
 use strict;
 use warnings;
 
+our $VERSION = '0.014'; # VERSION
+
 use App::Oozie::Constants qw(
     RE_OOZIE_ID
     VALID_JOB_TYPES
@@ -105,15 +107,11 @@ __END__
 
 =pod
 
-=encoding UTF-8
+=encoding utf8
 
 =head1 NAME
 
-App::Oozie::Types::Common
-
-=head1 VERSION
-
-version 0.013
+App::Oozie::Types::Common - Internal types.
 
 =head1 SYNOPSIS
 
@@ -123,10 +121,6 @@ version 0.013
 
 Internal types.
 
-=head1 NAME
-
-App::Oozie::Types::Common - Internal types.
-
 =head1 Types
 
 =head2 IsBUNDLEID
@@ -151,25 +145,4 @@ App::Oozie::Types::Common - Internal types.
 
 L<App::Oozie>.
 
-=head1 AUTHORS
-
-=over 4
-
-=item *
-
-David Morel
-
-=item *
-
-Burak Gursoy
-
-=back
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2023 by Booking.com.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
