@@ -1,9 +1,11 @@
 package App::Oozie::Types::DateTime;
-$App::Oozie::Types::DateTime::VERSION = '0.013';
+
 use 5.014;
 use strict;
 use warnings;
 
+our $VERSION = '0.014'; # VERSION
+
 use App::Oozie::Date;
 use App::Oozie::Constants qw(
     SHORTCUT_METHODS
@@ -78,15 +80,11 @@ __END__
 
 =pod
 
-=encoding UTF-8
+=encoding utf8
 
 =head1 NAME
 
-App::Oozie::Types::DateTime
-
-=head1 VERSION
-
-version 0.013
+App::Oozie::Types::DateTime - Internal types.
 
 =head1 SYNOPSIS
 
@@ -96,10 +94,6 @@ version 0.013
 
 Internal types.
 
-=head1 NAME
-
-App::Oozie::Types::DateTime - Internal types.
-
 =head1 Types
 
 =head2 IsDate
@@ -116,25 +110,4 @@ App::Oozie::Types::DateTime - Internal types.
 
 L<App::Oozie>.
 
-=head1 AUTHORS
-
-=over 4
-
-=item *
-
-David Morel
-
-=item *
-
-Burak Gursoy
-
-=back
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2023 by Booking.com.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
