@@ -1,10 +1,11 @@
-## no critic (RequireStrictDeclarations ProhibitUselessNoCritic)
 package App::Oozie::Types::States;
-$App::Oozie::Types::States::VERSION = '0.013';
+
 use 5.014;
 use strict;
 use warnings;
 
+our $VERSION = '0.014'; # VERSION
+
 use Type::Library -base;
 use Type::Utils -all;
 
@@ -31,15 +32,11 @@ __END__
 
 =pod
 
-=encoding UTF-8
+=encoding utf8
 
 =head1 NAME
 
-App::Oozie::Types::States
-
-=head1 VERSION
-
-version 0.013
+App::Oozie::Types::States - Internal types.
 
 =head1 SYNOPSIS
 
@@ -49,10 +46,6 @@ version 0.013
 
 Internal types.
 
-=head1 NAME
-
-App::Oozie::Types::States - Internal types.
-
 =head1 Types
 
 =head2 IsOozieStateRerunnable
@@ -67,25 +60,4 @@ App::Oozie::Types::States - Internal types.
 
 L<App::Oozie>.
 
-=head1 AUTHORS
-
-=over 4
-
-=item *
-
-David Morel
-
-=item *
-
-Burak Gursoy
-
-=back
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2023 by Booking.com.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
