@@ -1,10 +1,15 @@
 package App::Oozie::Types::Workflow;
-$App::Oozie::Types::Workflow::VERSION = '0.013';
+
 use 5.014;
 use strict;
 use warnings;
 
-use App::Oozie::Constants qw( RE_LINEAGE_DATA_ITEM );
+our $VERSION = '0.014'; # VERSION
+
+use App::Oozie::Constants qw(
+    RE_LINEAGE_DATA_ITEM
+    MIN_LEN_JUSTIFICATION
+);
 use Email::Valid;
 use Sub::Quote qw( quote_sub );
 use Type::Library -base;
@@ -34,6 +39,7 @@ my $LineageDataItem = declare LineageDataItem => as Str,
     ),
 ;
 
+my $Justification_min_len = MIN_LEN_JUSTIFICATION;
 my $Justification = declare Justification => as Str,
     constraint => quote_sub(
         q{
@@ -55,7 +61,7 @@ my $Justification = declare Justification => as Str,
             return 1;
         },
         {
-           '$min_length' => \200,
+           '$min_length' => \$Justification_min_len,
         },
     ),
 ;
@@ -96,15 +102,11 @@ __END__
 
 =pod
 
-=encoding UTF-8
+=encoding utf8
 
 =head1 NAME
 
-App::Oozie::Types::Workflow
-
-=head1 VERSION
-
-version 0.013
+App::Oozie::Types::Workflow - Internal types.
 
 =head1 SYNOPSIS
 
@@ -114,10 +116,6 @@ version 0.013
 
 Internal types.
 
-=head1 NAME
-
-App::Oozie::Types::Workflow - Internal types.
-
 =head1 Types
 
 =head2 DummyWorkflowMeta
@@ -134,25 +132,4 @@ App::Oozie::Types::Workflow - Internal types.
 
 L<App::Oozie>.
 
-=head1 AUTHORS
-
-=over 4
-
-=item *
-
-David Morel
-
-=item *
-
-Burak Gursoy
-
-=back
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2023 by Booking.com.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
