@@ -1,10 +1,18 @@
 package App::Oozie::Update::Coordinator;
-$App::Oozie::Update::Coordinator::VERSION = '0.013';
+
 use 5.014;
 use strict;
 use warnings;
+
+our $VERSION = '0.014'; # VERSION
+
 use namespace::autoclean -except => [qw/_options_data _options_config/];
 
+use App::Oozie::Constants qw(
+    EMPTY_STRING
+    ONE_HOUR
+    RE_EQUAL
+);
 use App::Oozie::Types::Common qw( IsCOORDID );
 use App::Oozie::Util::Misc qw( resolve_tmp_dir );
 
@@ -31,6 +39,7 @@ USAGE
 with qw(
     App::Oozie::Role::Log
     App::Oozie::Role::Fields::Common
+    App::Oozie::Role::Info
 );
 
 option coord => (
@@ -67,7 +76,13 @@ sub run {
     my $self   = shift;
     my $logger = $self->logger;
 
-    $logger->info( 'Starting' . ( $self->verbose ? '' : '. Enable --verbose to see more information' ) );
+    $logger->info(
+        sprintf 'Starting%s',
+                $self->verbose  ? EMPTY_STRING
+                                : '. Enable --verbose to see more information',
+    );
+
+    $self->log_versions if $self->verbose;
 
     my($job_meta, $job_properties) = $self->collect_current_conf;
 
@@ -102,7 +117,7 @@ sub run {
         push @{ $command }, '-dryrun' if $self->dryrun;
 
         $logger->info(
-            sprintf "Updating the coordinator (%s) attempt: %s",
+            sprintf 'Updating the coordinator (%s) attempt: %s',
                         $self->coord,
                         $try,
         );
@@ -118,22 +133,40 @@ sub run {
 
         if ( ! $success ) {
             if ( $out ) {
-                $state->{fix_starttime} = 1 if $out =~ /Start time can\'t be changed/;
-                $state->{fix_endtime}   = 1 if $out =~ /End time can\'t be changed/;
+                if ( $out =~ m{ \QStart time can't be changed\E }xms ) {
+                    $state->{fix_starttime} = 1;
+                }
+
+                if ( $out =~ m{ \QEnd time can't be changed\E }xms ) {
+                    $state->{fix_endtime} = 1;
+                }
             }
             else {
-                $logger->warn( sprintf "Coordinator %s update failed (%s): %s", $self->coord, $self->dryrun ? ' (dryrun)' : '', $out // '[no output]' );
+                $logger->warn(
+                    sprintf 'Coordinator %s update failed (%s): %s',
+                                $self->coord,
+                                $self->dryrun ? ' (dryrun)' : EMPTY_STRING,
+                                $out // '[no output]',
+                );
             }
             next TRY;
         }
 
-        $logger->info( sprintf "Coordinator %s updated%s", $self->coord, $self->dryrun ? ' (dryrun)' : '' );
+        $logger->info(
+            sprintf 'Coordinator %s updated%s',
+                        $self->coord,
+                        $self->dryrun ? ' (dryrun)' : EMPTY_STRING,
+        );
 
         last TRY;
     }
 
     if ( ! $success ) {
-        $logger->fatal( sprintf "Coordinator %s was NOT updated%s.", $self->coord, $self->dryrun ? ' (dryrun)' : '' );
+        $logger->fatal(
+            sprintf 'Coordinator %s was NOT updated%s.',
+                        $self->coord,
+                        $self->dryrun ? ' (dryrun)' : EMPTY_STRING,
+        );
         if ( $last_out ) {
             $logger->fatal( $last_out );
             if ( $last_out =~ m{ \QFrequency can't be changed\E }xms ) {
@@ -164,13 +197,13 @@ sub collect_current_conf {
 
     eval {
         my $oozie           = $self->oozie;
-        my $job             = $oozie->job( $coord ) || die "No configuration for the job: $coord";
-        $oozie_build        = $oozie->new->build_version  || die "Failed to get the Oozie server version!";
+        my $job             = $oozie->job( $coord )       || die sprintf 'No configuration for the job: %s', $coord;
+        $oozie_build        = $oozie->new->build_version  || die 'Failed to get the Oozie server version!';
         my @vtuple          = split m{ \Q-cdh\E }xms, $oozie_build;
-        $oozie_version      = shift @vtuple               || die "Unable to determine the Oozie server version from $oozie_build";
-        $oozie_cdh_version  = shift @vtuple               || die "Unable to determine the Oozie server CDH version from $oozie_build";
-        $current_coord_user = $job->{user}                || die "Failed to locate the user running $coord";
-        $current_xml        = $job->{conf}                || die "No configuration for the job: $coord";
+        $oozie_version      = shift @vtuple               || die sprintf 'Unable to determine the Oozie server version from %s', $oozie_build;
+        $oozie_cdh_version  = shift @vtuple               || die sprintf 'Unable to determine the Oozie server CDH version from %s', $oozie_build;
+        $current_coord_user = $job->{user}                || die sprintf 'Failed to locate the user running %s', $coord;
+        $current_xml        = $job->{conf}                || die sprintf 'No configuration for the job: %s', $coord;
         # If you extend the coordinator, then this data gets updated but the
         # XML config will retain the old and meaningless record. While
         # it should be fine for the startTime, it will be bogus for the endTime
@@ -179,9 +212,9 @@ sub collect_current_conf {
         # to update everything but the scheduling. For some reason XML conf
         # does not get updated.
         #
-        $meta_startTime     = $job->{startTime}           || die "No startTime set for the job: $coord";
-        $meta_endTime       = $job->{endTime}             || die "No endTime set for the job: $coord";
-        my $path            = $job->{coordJobPath}        || die "No coordJobPath defined for the job: $coord"; # shouldn't happen
+        $meta_startTime     = $job->{startTime}           || die sprintf 'No startTime set for the job: %s', $coord;
+        $meta_endTime       = $job->{endTime}             || die sprintf 'No endTime set for the job: %s', $coord;
+        my $path            = $job->{coordJobPath}        || die sprintf 'No coordJobPath defined for the job: %s', $coord; # shouldn't happen
         my $hdfs_dest       = $self->default_hdfs_destination;
         ($base_path         = $path) =~ s{ \A $hdfs_dest [/]? }{}xms;
         my $jp_hdfs_path    = catfile $path,      'job.properties';
@@ -195,9 +228,15 @@ sub collect_current_conf {
         }
         elsif ( -e $jp_local_path ) {
             $logger->info( sprintf 'job.properties exists on local file system. Fetching %s', $jp_local_path );
-            open my $FH, '<', $jp_local_path or die "Can't read $jp_local_path: $!";
+            open my $FH, '<', $jp_local_path or die sprintf q{Can't read %s: %s}, $jp_local_path, $!;
             $jp =  do { local $/; <$FH> };
-            close $FH;
+            if ( ! close $FH ) {
+                $logger->warn(
+                    sprintf 'Failed to close %s: %s',,
+                                $jp_local_path,
+                                $!,
+                );
+            }
         }
         else {
             my $uh_oh = sprintf <<'FYI', Cwd::getcwd, $base_path;
@@ -236,7 +275,7 @@ FYI
     } or do {
         my $eval_error = $@ || 'Zombie error';
         $logger->fatal(
-            sprintf "Could not get config for job %s: %s",
+            sprintf 'Could not get config for job %s: %s',
                         $coord,
                         $eval_error,
         );
@@ -244,9 +283,9 @@ FYI
     };
 
     if ( $self->verbose ) {
-        $logger->debug( "Start Current XML configuration");
+        $logger->debug( 'Start Current XML configuration' );
         $logger->debug( $current_xml );
-        $logger->debug( "End Current XML configuration");
+        $logger->debug( 'End Current XML configuration' );
     }
 
     my $show_cmd_output;
@@ -254,7 +293,7 @@ FYI
         && $self->effective_username ne $current_coord_user
     ) {
         $logger->warn(
-            sprintf "Current user `%s` is not the same as the coordinator user: `%s`. Will attempt to impersonate",
+            sprintf 'Current user `%s` is not the same as the coordinator user: `%s`. Will attempt to impersonate.',
                         $self->effective_username,
                         $current_coord_user,
         );
@@ -279,7 +318,7 @@ sub offset_one_hour {
     # coord update bug linked to oozie 3 and DST
     return Date::Format::time2str(
                 '%Y-%m-%dT%H:%MZ',
-                Date::Parse::str2time( $time->text ) - 3600,
+                Date::Parse::str2time( $time->text ) - ONE_HOUR,
                 'UTC',
             );
 }
@@ -298,16 +337,21 @@ sub _modify_xml {
         if $self->verbose;
 
     my $twig = XML::Twig->new->parse( ${ $current_xml_ref } )
-                or die "Could not parse the original configuration";
+                or die 'Could not parse the original configuration';
 
     # clean up former mistakes...
     for my $elem ( $twig->root->children ) {
-         $elem->delete if $elem->first_child_text =~ /^"oozie\./;
+        if ( $elem->first_child_text =~ m{ \A ["]oozie[.] }xms ) {
+            $elem->delete;
+        }
     }
 
     SYNC_END_TIME_IN_XML_CONF: {
         for my $elem ( $twig->root->children ) {
-            for my $date_field (qw/ endTime startTime /) {
+            for my $date_field (qw/
+                endTime
+                startTime
+            /) {
                 if ( $elem->first_child_text eq $date_field ) {
                     my($cur) = $elem->get_xpath('./value');
                     my $meta_val = $date_field eq 'endTime'   ? $meta_endTime
@@ -397,7 +441,7 @@ sub _modify_xml {
     }
 
     for ( @{ $self->define } ) {
-        my ( $k, $v ) = split /=/, $_, 2;
+        my ( $k, $v ) = split RE_EQUAL, $_, 2;
         $twig->root->insert_new_elt(
             'last_child',
             'property',
@@ -450,16 +494,22 @@ sub _show_twig {
     my $twig   = shift;
     my $logger = $self->logger;
 
-    open my $BUF, '>', \my $dump
-        or die "Failed to create an in-memory filehandle: $!";
+    $logger->debug( 'Start new XML configuration' );
 
-    $logger->debug( "Start new XML configuration" );
+    open my $BUF, '>', \my $dump
+        or die sprintf 'Failed to create an in-memory filehandle: %s', $!;
 
     $twig->flush( $BUF );
-    close $BUF;
+
+    if ( ! close $BUF ) {
+        $logger->warn(
+            sprintf 'Failed to close in-memory XML file: %s',
+                        $!,
+        );
+    }
 
     $logger->debug( $dump );
-    $logger->debug( "End new XML configuration" );
+    $logger->debug( 'End new XML configuration' );
 
     return;
 }
@@ -470,15 +520,11 @@ __END__
 
 =pod
 
-=encoding UTF-8
+=encoding utf8
 
 =head1 NAME
 
-App::Oozie::Update::Coordinator
-
-=head1 VERSION
-
-version 0.013
+App::Oozie::Update::Coordinator - Updates the running coordinator.
 
 =head1 SYNOPSIS
 
@@ -489,10 +535,6 @@ version 0.013
 
 This is an action/program in the Oozie Tooling.
 
-=head1 NAME
-
-App::Oozie::Update::Coordinator - Updates the running coordinator.
-
 =head1 Methods
 
 =head2 run
@@ -519,25 +561,4 @@ App::Oozie::Update::Coordinator - Updates the running coordinator.
 
 L<App::Oozie>.
 
-=head1 AUTHORS
-
-=over 4
-
-=item *
-
-David Morel
-
-=item *
-
-Burak Gursoy
-
-=back
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2023 by Booking.com.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
