@@ -1,9 +1,11 @@
 package App::Oozie::Util::Log4perl;
-$App::Oozie::Util::Log4perl::VERSION = '0.013';
+
 use 5.014;
 use strict;
 use warnings;
 
+our $VERSION = '0.014'; # VERSION
+
 use App::Oozie::Util::Plugin qw(
     find_files_in_inc
     find_plugins
@@ -18,7 +20,7 @@ sub find_template {
     my @found = find_files_in_inc('App/Oozie/Util/Log4perl/Templates', 'l4p');
     my %tmpl = map { @{ $_ }{qw/ name abs_path /} } @found;
 
-    return $tmpl{ $type } || $tmpl{simple} || die "No log4perl template file was found";
+    return $tmpl{ $type } || $tmpl{simple} || die 'No log4perl template file was found';
 }
 
 1;
@@ -27,15 +29,11 @@ __END__
 
 =pod
 
-=encoding UTF-8
+=encoding utf8
 
 =head1 NAME
 
-App::Oozie::Util::Log4perl
-
-=head1 VERSION
-
-version 0.013
+App::Oozie::Util::Log4perl - Helper for handling the Log4perl template.
 
 =head1 SYNOPSIS
 
@@ -46,10 +44,6 @@ version 0.013
 
 Internal module.
 
-=head1 NAME
-
-App::Oozie::Util::Log4perl - Helper for handling the Log4perl template.
-
 =head1 Methods
 
 =head2 find_template
@@ -58,25 +52,4 @@ App::Oozie::Util::Log4perl - Helper for handling the Log4perl template.
 
 L<App::Oozie>.
 
-=head1 AUTHORS
-
-=over 4
-
-=item *
-
-David Morel
-
-=item *
-
-Burak Gursoy
-
-=back
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2023 by Booking.com.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
