@@ -1,10 +1,12 @@
 package App::Oozie::Util::Plugin;
-$App::Oozie::Util::Plugin::VERSION = '0.013';
+
 use 5.014;
 use strict;
 use warnings;
 use parent qw( Exporter );
 
+our $VERSION = '0.014'; # VERSION
+
 use File::Spec::Functions qw(
     catdir
     catfile
@@ -18,22 +20,22 @@ our @EXPORT_OK = qw(
 );
 
 sub find_plugins {
-    my $base_class = shift || die "Please specify a base class name";
+    my $base_class = shift || die 'Please specify a base class name';
     my $fext       = shift || 'pm';
 
     (my $base_path = $base_class) =~ s{::}{/}xmsg;
 
     my @found = find_files_in_inc( $base_path, $fext );
     my %action_to_class = map {
-        lc( $_->{name} ) => $base_class . '::' . $_->{name}
+        lc( $_->{name} ) => $base_class . q{::} . $_->{name}
     } @found;
 
     return \%action_to_class;
 }
 
 sub find_files_in_inc {
-    my $base_path = shift || die "base_path not specified";
-    my $fext      = shift || die "File exrentension not specified";
+    my $base_path = shift || die 'base_path not specified';
+    my $fext      = shift || die 'File exrentension not specified';
 
     my $re_file_extension = qr{
         [.] $fext
@@ -44,8 +46,7 @@ sub find_files_in_inc {
     for my $path ( @INC ) {
         my $test = catdir $path, $base_path;
         next if ! -d $test || ! -e _;
-        opendir my $DIR, $test or die "Can't opendir $test: $!";
-        my @wanted;
+        opendir my $DIR, $test or die sprintf q{Can't opendir %s: %s}, $test, $!;
         while ( my $file = readdir $DIR ) {
             my $fp = catfile $test, $file;
             next if    $seen_path{ $fp }++
@@ -67,7 +68,7 @@ sub find_files_in_inc {
 }
 
 sub load_plugin {
-    my $class = shift || die "No class specified for loading";
+    my $class = shift || die 'No class specified for loading';
     eval qq{
         require $class;
         1;
@@ -84,15 +85,11 @@ __END__
 
 =pod
 
-=encoding UTF-8
+=encoding utf8
 
 =head1 NAME
 
-App::Oozie::Util::Plugin
-
-=head1 VERSION
-
-version 0.013
+App::Oozie::Util::Plugin; - Utility for polugin handling.
 
 =head1 SYNOPSIS
 
@@ -106,10 +103,6 @@ version 0.013
 
 Internal utility.
 
-=head1 NAME
-
-App::Oozie::Util::Plugin; - Utility for polugin handling.
-
 =head1 Methods
 
 =head2 find_files_in_inc
@@ -122,25 +115,4 @@ App::Oozie::Util::Plugin; - Utility for polugin handling.
 
 L<App::Oozie>.
 
-=head1 AUTHORS
-
-=over 4
-
-=item *
-
-David Morel
-
-=item *
-
-Burak Gursoy
-
-=back
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2023 by Booking.com.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
